###
###

.genome <- "GRCh38"

.onLoad <- function(libname, pkgname)
{
    msg <- c("Package ", pkgname, " is deprecated. Please use an XtraSNPlocs ",
             "data package based on a more recent dbSNP Build instead. ",
             "Call BSgenome::available.SNPs() to get the list of ",
             "available XtraSNPlocs data packages.")
    .Deprecated(msg=c("  ", wmsg(msg)))

    extdata_dirpath <- system.file("extdata", package=pkgname,
                                   lib.loc=libname, mustWork=TRUE)

    ## Make Seqinfo object.
    seqinfo_path <- file.path(extdata_dirpath, "seqinfo.txt")
    seqtable <- read.table(seqinfo_path, stringsAsFactors=FALSE)
    seqnames <- seqtable[[1L]]
    seqinfo <- Seqinfo(
        seqnames=seqnames,
        seqlengths=seqtable[[2L]],
        isCircular=seqtable[[3L]],
        genome=.genome
    )

    ## Make GenomeDescription object.
    reference_genome <- GenomeDescription(
        organism="Homo sapiens",
        species="Human",
        provider="NCBI",
        provider_version=.genome,
        release_date="2013-12-17",
        release_name="Genome Reference Consortium Human Build 38",
        seqinfo=seqinfo
    )

    ## Make and export XtraSNPlocs object.
    xtra_snps <- newXtraSNPlocs(
        pkgname,
        extdata_dirpath,
        provider="dbSNP",
        provider_version="dbSNP Human BUILD 141",
        release_date="May 2014",
        release_name="dbSNP Human BUILD 141",
        download_url="ftp://ftp.ncbi.nih.gov/snp/organisms/human_9606/ASN1_flat/",
        download_date="Sep 9, 2014",
        reference_genome=reference_genome
    )

    ns <- asNamespace(pkgname)

    objname <- pkgname
    assign(objname, xtra_snps, envir=ns)
    namespaceExport(ns, objname)
}

